@@ -1,5 +1,5 @@
 package Bio::Tools::Run::Alignment::TCoffee;
-$Bio::Tools::Run::Alignment::TCoffee::VERSION = '1.7.3';
+$Bio::Tools::Run::Alignment::TCoffee::VERSION = '1.7.4';
 use utf8;
 use strict;
 use warnings;
@@ -128,6 +128,14 @@ sub version {
 }
 
 
+sub _major_minor_version {
+    my ($self) = @_;
+    my $version = $self->version;
+    $version =~ s/(\d+\.\d+)[\D].*$/$1/;
+    return $version;
+}
+
+
 sub run{
    my ($self,@args) = @_;
    my ($type,$seq,$profile) = $self->_rearrange([qw(TYPE
@@ -217,7 +225,8 @@ sub _run {
         # in later versions (tested on 5.72 and 7.54) the API for profile
         # alignment changed. This attempts to do the right thing for older
         # versions but corrects for newer ones
-        if ($self->version && $self->version < 5) {
+        if ($self->_major_minor_version
+            && $self->_major_minor_version < 5) {
             # this breaks severely on newer TCoffee (>= v5)
             unless (($self->matrix =~ /none/i) || ($self->matrix =~ /null/i) ) {
                 $instring = '-in='.join(',',
@@ -450,7 +459,8 @@ sub _setparams {
 
     # -no_warning is required on some systems with certain versions or failure
     # is guaranteed
-    if ($self->version >= 4 && $self->version < 4.7) {
+    if ($self->_major_minor_version >= 4
+        && $self->_major_minor_version < 4.7) {
         $param_string .= ' -no_warning';
     }
 
@@ -496,7 +506,7 @@ Bio::Tools::Run::Alignment::TCoffee - Object for the calculation of a multiple s
 
 =head1 VERSION
 
-version 1.7.3
+version 1.7.4
 
 =head1 SYNOPSIS
 
@@ -559,6 +569,13 @@ webserver environment has the proper PATH set or use the options 2 or
 
 =head1 INTERNAL METHODS
 
+=head2 _numeric_version
+
+Version "numbers" are not numeric values.  In the case of T-Coffee,
+they have an hash component at their end.  This was not the case in
+older releases.  We use the first two numeric parts to do different
+things though.  See also issue #1.
+
 =head2 _run
 
  Title   :  _run
@@ -1026,10 +1043,10 @@ object, or through get/set methods of the same name (lowercase).
 =head2 version
 
  Title   : version
- Usage   : exit if $prog->version() < 1.8
+ Usage   : $prog->version()
  Function: Determine the version number of the program
  Example :
- Returns : float or undef
+ Returns : string
  Args    : none
 
 =head2 run
